@@ -5,9 +5,13 @@ import java.util.ArrayList;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.DeleteRowsSession;
-import org.gcube.portlets.user.td.tablewidget.client.progress.DeleteRowsProgressDialog;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
 import org.gcube.portlets.user.td.tablewidget.client.util.UtilsGXT3;
+import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
+import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
+import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableWhy;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
@@ -21,13 +25,12 @@ import com.google.web.bindery.event.shared.EventBus;
  * @author "Giancarlo Panichi"
  * 
  */
-public class DeleteRows {
+public class DeleteRows implements MonitorDialogListener  {
 	protected TRId trId;
 	protected EventBus eventBus;
 	protected ArrayList<String> rows;
 	protected DeleteRowsSession deleteRowsSession;
-	protected DeleteRowsProgressDialog deleteRowsProgressDialog;
-
+	
 	public DeleteRows(TRId trId, ArrayList<String> rows, EventBus eventBus) {
 		this.trId = trId;
 		this.rows = rows;
@@ -41,7 +44,7 @@ public class DeleteRows {
 
 	protected void onDelete() {
 		TDGWTServiceAsync.INSTANCE.startDeleteRows(deleteRowsSession,
-				new AsyncCallback<Void>() {
+				new AsyncCallback<String>() {
 
 					public void onFailure(Throwable caught) {
 						if (caught instanceof TDGWTSessionExpiredException) {
@@ -56,13 +59,65 @@ public class DeleteRows {
 						}
 					}
 
-					public void onSuccess(Void result) {
-						deleteRowsProgressDialog = new DeleteRowsProgressDialog(
-								deleteRowsSession, eventBus);
+					public void onSuccess(String taskId) {
+						openMonitorDialog(taskId);
 					}
 
 				});
 
 	}
+	
+	protected void close() {
+		/*if (parent != null) {
+			parent.close();
+		}
+		*/
+	}
+
+	// /
+	protected void openMonitorDialog(String taskId) {
+		MonitorDialog monitorDialog = new MonitorDialog(taskId, eventBus);
+		monitorDialog.addProgressDialogListener(this);
+		monitorDialog.show();
+	}
+
+	@Override
+	public void operationComplete(TRId trId) {
+		ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
+		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+				ChangeTableRequestType.DELETEROWS, trId, why);
+		eventBus.fireEvent(changeTableRequestEvent);
+		close();
+	}
+
+	@Override
+	public void operationFailed(Throwable caught, String reason, String details) {
+		UtilsGXT3.alert(reason, details);
+		close();
+
+	}
+
+	@Override
+	public void operationStopped(TRId trId, String reason, String details) {
+		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
+		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+				ChangeTableRequestType.DELETEROWS, trId, why);
+		eventBus.fireEvent(changeTableRequestEvent);
+		close();
+
+	}
+
+	@Override
+	public void operationAborted() {
+		close();
+
+	}
+
+	@Override
+	public void operationPutInBackground() {
+		close();
+
+	}
+
 
 }
